==> Update%20from%20v1.0.1%20to%20v1.0.2.zip: labels.blade.php <==
 <script>

     var label_please_wait = '{{ get_label('please_wait', 'Please wait...') }}';
     var label_please_select_records_to_delete =
     '{{ get_label('please_select_records_to_delete', 'Please select records to delete.') }}';
     var label_something_went_wrong = '{{ get_label('something_went_wrong', 'Something went wrong.') }}';
     var label_please_correct_errors = '{{ get_label('please_correct_errors', 'Please correct errors.') }}';
     var label_project_removed_from_favorite_successfully =
     '{{ get_label('project_removed_from_favorite_successfully', 'Project removed from favorite successfully.') }}';
     var label_project_marked_as_favorite_successfully =
     '{{ get_label('project_marked_as_favorite_successfully', 'Project marked as favorite successfully.') }}';
     var label_yes = '{{ get_label('yes', 'Yes') }}';
     var label_upload = '{{ get_label('upload', 'Upload') }}';
     var decimal_points = {{ intval($general_settings['decimal_points_in_currency'] ?? '2') }};
     var label_update = '{{ get_label('update', 'Update') }}';
     var label_delete = '{{ get_label('delete', 'Delete') }}';
     var label_view = '{{ get_label('view', 'View') }}';
     var label_not_assigned = '{{ get_label('not_assigned', 'Not assigned') }}';
     var label_delete_selected = '{{ get_label('delete_selected', 'Delete selected') }}';
     var label_search = '{{ get_label('search', 'Search') }}';
     var label_create = '{{ get_label('create', 'Create') }}';

     var label_min_0 = '{{ get_label('value_must_be_greater_then_0', 'Value must be greater than 0') }}';
     var label_max_100 = '{{ get_label('not_greater_then_100', 'Not greater than 100') }}';
     </script>

==> Update%20from%20v1.0.2%20to%20v1.03.zip: labels.blade.php <==
 <script>
     var label_please_wait = '{{ get_label('please_wait', 'Please wait...') }}';
     var label_please_select_records_to_delete =
     '{{ get_label('please_select_records_to_delete', 'Please select records to delete.') }}';
     var label_something_went_wrong = '{{ get_label('something_went_wrong', 'Something went wrong.') }}';
     var label_please_correct_errors = '{{ get_label('please_correct_errors', 'Please correct errors.') }}';
     var label_project_removed_from_favorite_successfully =
     '{{ get_label('project_removed_from_favorite_successfully', 'Project removed from favorite successfully.') }}';
     var label_project_marked_as_favorite_successfully =
     '{{ get_label('project_marked_as_favorite_successfully', 'Project marked as favorite successfully.') }}';
     var label_yes = '{{ get_label('yes', 'Yes') }}';
     var label_upload = '{{ get_label('upload', 'Upload') }}';
     var decimal_points = {{ intval($general_settings['decimal_points_in_currency'] ?? '2') }};
     var label_update = '{{ get_label('update', 'Update') }}';
     var label_delete = '{{ get_label('delete', 'Delete') }}';
     var label_view = '{{ get_label('view', 'View') }}';
     var label_not_assigned = '{{ get_label('not_assigned', 'Not assigned') }}';
     var label_delete_selected = '{{ get_label('delete_selected', 'Delete selected') }}';
     var label_search = '{{ get_label('search', 'Search') }}';
     var label_create = '{{ get_label('create', 'Create') }}';
     var label_min_0 = '{{ get_label('value_must_be_greater_then_0', 'Value must be greater than 0') }}';
     var label_max_100 = '{{ get_label('not_greater_then_100', 'Not greater than 100') }}';

       var label_set_as_default_view = '<?= get_label('set_as_default_view', 'Set as Default View') ?>';
     var label_users_associated_with_project = '<?= get_label('users_associated_with_project', 'Users associated with project') ?>';
    var label_update_task = '<?= get_label('update_task', 'Update Task') ?>';
    var label_quick_view = '<?= get_label('quick_view', 'Quick View') ?>';
    var label_project = '<?= get_label('project', 'Project') ?>';
    var label_task = '<?= get_label('task', 'Task') ?>';
    var label_projects = '<?= get_label('projects', 'Projects') ?>';
    var label_tasks = '<?= get_label('tasks', 'Tasks') ?>';
    var label_clear_filters = '<?= get_label('clear_filters', 'Clear Filters') ?>';
    var label_set_as_default_view = '<?= get_label('set_as_default_view', 'Set as Default View') ?>';
    var label_default_view = '<?= get_label('default_view', 'Default View') ?>';
    var label_save_column_visibility = '<?= get_label('save_column_visibility', 'Save Column Visibility') ?>';
     </script>
